local mod = ...


-- Register unlockable building ----------------------------------------------------------------------
local function registerUnlockableBuilding(nameBuilding, nameEstate, qtyInfluence, listPrereq)

    mod:registerAsset({
        DataType = "UNLOCKABLE_BUILDING",
        Id = "UNLOCKABLE_IAE_" .. nameBuilding,
        Name = "UNLOCKABLE_IAE_" .. nameBuilding .. "_NAME",
        Description = "UNLOCKABLE_IAE_" .. nameBuilding .. "_DESC",
        EstateInfluenceCostList = {
            {
                Estate = nameEstate,
                Quantity = qtyInfluence,
            },
        },
        PrerequisiteUpgrades = listPrereq,
        IsRecurrent = false,
        IsComingSoon = false,
        DaysBeforeBuyingAgain = 0,
        UnlockableImage = nil,
        AssetBuilding = nameBuilding,
    })

    -- return "UNLOCKABLE_IAE_" .. nameBuilding

end

-- registerUnlockableBuilding("BUILDING_GRANARY", "LABOUR", 5, nil )
-- registerUnlockableBuilding("MONUMENT_MARKET", "LABOUR", 5, {"UNLOCKABLE_IAE_BUILDING_GRANARY"} )
-- registerUnlockableBuilding("BUILDING_FISHING_HUT", "LABOUR", 5, {"UNLOCKABLE_IAE_BUILDING_GRANARY"} )
-- registerUnlockableBuilding("BUILDING_WAREHOUSE", "LABOUR", 5, nil )
registerUnlockableBuilding("BUILDING_FISHING_HUT", "LABOUR", 5, nil )
registerUnlockableBuilding("BUILDING_WHEAT_FARM", "LABOUR", 10, nil )
registerUnlockableBuilding("BUILDING_WINDMILL", "LABOUR", 10, nil )
registerUnlockableBuilding("BUILDING_BAKERY", "LABOUR", 10, nil )
registerUnlockableBuilding("BUILDING_HOP_FARM", "LABOUR", 20, nil )
registerUnlockableBuilding("BUILDING_BREWERY", "LABOUR", 20, nil )
registerUnlockableBuilding("MONUMENT_TAVERN", "LABOUR", 40, nil )

registerUnlockableBuilding("BUILDING_BUILDER_WORKSHOP", "LABOUR", 5, nil )
registerUnlockableBuilding("BUILDING_COAL_HUT", "KINGDOM", 5, nil )
registerUnlockableBuilding("BUILDING_STONEMASON_HUT", "KINGDOM", 5, nil )

registerUnlockableBuilding("BUILDING_SHEEP_FARM", "KINGDOM", 10, nil )
registerUnlockableBuilding("BUILDING_DAIRY_FARM", "KINGDOM", 10, nil )
registerUnlockableBuilding("BUILDING_WEAVER_HUT", "KINGDOM", 10, nil )
registerUnlockableBuilding("BUILDING_TAILOR_WORKSHOP", "KINGDOM", 10, nil )
registerUnlockableBuilding("BUILDING_CHEESE_MAKER", "KINGDOM", 10, nil )
registerUnlockableBuilding("MONUMENT_WOODEN_KEEP", "KINGDOM", 20, nil )
registerUnlockableBuilding("BUILDING_GLASS_SMELTER", "KINGDOM", 20, nil )
registerUnlockableBuilding("BUILDING_JEWELER_WORKSHOP", "KINGDOM", 20, nil )
registerUnlockableBuilding("BUILDING_COOPERAGE", "KINGDOM", 20, nil )
registerUnlockableBuilding("BUILDING_BLACKSMITH", "KINGDOM", 20, nil )
registerUnlockableBuilding("BUILDING_WEAPONSMITH", "KINGDOM", 20, nil )

registerUnlockableBuilding("MONUMENT_RUSTIC_CHURCH", "CLERGY", 10, nil )
registerUnlockableBuilding("MONUMENT_LEGACY_RUSTIC_CHURCH", "CLERGY", 10, nil )
registerUnlockableBuilding("MONUMENT_ROMAN_CHURCH", "CLERGY", 10, nil )
registerUnlockableBuilding("MONUMENT_CHURCH", "CLERGY", 20, nil )
registerUnlockableBuilding("MONUMENT_STONE_BRIDGE", "CLERGY", 20, nil )
registerUnlockableBuilding("MONUMENT_MONASTERY", "CLERGY", 40, nil )

mod:overrideAsset({
    Id = "UNLOCKABLE_LABOUR_WAREHOUSE",
    EstateInfluenceCostList = {
        {
            Estate = "LABOUR",
            Quantity = 5,
        },
    },
})



-- Vanilla building part list ---------------------------------------------------------------------
local function overrideUnlockableBuildingPartList(nameBuildingList, nameEstate, qtyInfluence, listPrereq)

    mod:overrideAsset({
        DataType = "UNLOCKABLE_BUILDING_PART_LIST",
        Id = nameBuildingList,
        EstateInfluenceCostList = {
            {
                Estate = nameEstate,
                Quantity = qtyInfluence,
            },
        },
        PrerequisiteUpgrades = listPrereq,
    })

end

overrideUnlockableBuildingPartList("UNLOCKABLE_CLERGY_BUILDER_WORKSHOP_STAINED_GLASS_WORKSHOP", "LABOUR", 10, {"UNLOCKABLE_IAE_BUILDING_BUILDER_WORKSHOP"} )
overrideUnlockableBuildingPartList("UNLOCKABLE_LABOUR_BUILDER_WORKSHOP_SCULPTURE_WORKSHOP", "LABOUR", 10, {"UNLOCKABLE_IAE_BUILDING_BUILDER_WORKSHOP"} )
overrideUnlockableBuildingPartList("UNLOCKABLE_CLERGY_MONASTERY_APIARY", "CLERGY", 20, {"UNLOCKABLE_IAE_MONUMENT_MONASTERY"} )
overrideUnlockableBuildingPartList("UNLOCKABLE_CLERGY_MONASTERY_HERB_GARDEN", "CLERGY", 10, {"UNLOCKABLE_IAE_MONUMENT_MONASTERY"} )
overrideUnlockableBuildingPartList("UNLOCKABLE_CLERGY_MONASTERY_WINE_PRODUCTION", "CLERGY", 40, {"UNLOCKABLE_IAE_MONUMENT_MONASTERY"} )
overrideUnlockableBuildingPartList("UNLOCKABLE_CLERGY_RUSTIC_CHURCH_ADDITIONAL_PARTS", "CLERGY", 10, {"UNLOCKABLE_IAE_MONUMENT_RUSTIC_CHURCH"} )
overrideUnlockableBuildingPartList("UNLOCKABLE_KINGDOM_WOODEN_KEEP_DECORATIVE", "KINGDOM", 20, {"UNLOCKABLE_IAE_MONUMENT_WOODEN_KEEP"} )
overrideUnlockableBuildingPartList("UNLOCKABLE_LABOUR_LORD_MANOR_STONE_SET", "KINGDOM", 20, nil )
overrideUnlockableBuildingPartList("UNLOCKABLE_LABOUR_TAVERN_STONE_SET", "LABOUR", 20, {"UNLOCKABLE_IAE_MONUMENT_TAVERN"} )



-- Vanilla wall ---------------------------------------------------------------------
local function overrideUnlockableWall(nameWall, nameEstate, qtyInfluence, listPrereq)

    mod:overrideAsset({
        DataType = "UNLOCKABLE_WALL",
        Id = nameWall,
        EstateInfluenceCostList = {
            {
                Estate = nameEstate,
                Quantity = qtyInfluence,
            },
        },
        PrerequisiteUpgrades = listPrereq,
    })

end

overrideUnlockableWall("UNLOCKABLE_CLERGY_SMALL_STONE_WALL", "CLERGY", 5, nil )
overrideUnlockableWall("UNLOCKABLE_KINGDOM_LARGE_STONE_WALL", "CLERGY", 5, nil )
overrideUnlockableWall("UNLOCKABLE_KINGDOM_WOODEN_WALL", "CLERGY", 5, nil )
overrideUnlockableWall("UNLOCKABLE_LABOUR_HEDGE", "CLERGY", 5, nil )
overrideUnlockableWall("UNLOCKABLE_LABOUR_TAVERN_WALL", "CLERGY", 5, nil )



-- Modded buildings -----------------------------------------------------------------------------------
local function processMod(modGUID, nameBuilding, nameEstate, qtyInfluence, listPrereq)

    if foundation.isModLoaded(modGUID) then

        mod:overrideAsset({
            Id = nameBuilding,
            VillagerRequired = nil,
            IsManuallyUnlocked = true,
        })

        mod:registerAsset({
            DataType = "UNLOCKABLE_BUILDING",
            Id = "UNLOCKABLE_IAE_" .. nameBuilding,
            Name = "UNLOCKABLE_IAE_" .. nameBuilding .. "_NAME",
            Description = "UNLOCKABLE_IAE_" .. nameBuilding .. "_DESC",
            EstateInfluenceCostList = {
                {
                    Estate = nameEstate,
                    Quantity = qtyInfluence,
                },
            },
            PrerequisiteUpgrades = listPrereq,
            IsRecurrent = false,
            IsComingSoon = false,
            DaysBeforeBuyingAgain = 0,
            UnlockableImage = nil,
            AssetBuilding = nameBuilding,
        })

        return "UNLOCKABLE_IAE_" .. nameBuilding

    else
        return nil

    end

end

-- local unlockable_BUILDING_STORAGE = processMod("379a7c1c-777d-4f35-8042-7caa9c87d428", "BUILDING_STORAGE", "LABOUR", 10, {"UNLOCKABLE_IAE_BUILDING_GRANARY", "UNLOCKABLE_IAE_BUILDING_WAREHOUSE"})
local unlockable_BUILDING_STORAGE = processMod("379a7c1c-777d-4f35-8042-7caa9c87d428", "BUILDING_STORAGE", "LABOUR", 10, nil)
local unlockable_BUILDING_POULTRY = processMod("c8b63172-5b6d-45eb-9fab-a40c8ecd9947", "BUILDING_POULTRY", "LABOUR", 5, nil)
local unlockable_BUILDING_VEGETABLEFARM = processMod("c8b63172-5b6d-45eb-9fab-a40c8ecd9947", "BUILDING_VEGETABLEFARM", "LABOUR", 10, nil)
local unlockable_FISHPOND = processMod("0e119c21-edfd-4e2e-a079-0678b38c85c0", "FISHPOND", "LABOUR", 10, nil)
local unlockable_BUILDING_TREEFOLK = processMod("31ff1a31-a65d-41e9-b1f1-8405fc3f4632", "BUILDING_TREEFOLK", "LABOUR", 40, nil)
local unlockable_BUILDING_TRADINGPOST = processMod("9fc78b27-77d7-4f5f-96b2-464e458e3e06", "BUILDING_TRADINGPOST", "LABOUR", 20, nil)
local unlockable_BUILDING_HARBORTRADE = processMod("467b9d01-c8f4-42b5-a3a9-5b026376a6a3", "BUILDING_HARBORTRADE", "LABOUR", 40, nil)
local unlockable_BUILDING_ORCHARD = processMod("f252f14d-ca1d-4d02-97ca-46581d4b567d", "BUILDING_ORCHARD", "LABOUR", 10, nil)
local unlockable_BUILDING_CIDERPRESS = processMod("f252f14d-ca1d-4d02-97ca-46581d4b567d", "BUILDING_CIDERPRESS", "LABOUR", 20, nil)
local unlockable_BUILDING_ENTERTAINMENT = processMod("9475b42e-f880-4787-9b07-bec720fc90b6", "BUILDING_ENTERTAINMENT", "LABOUR", 10, nil)

local unlockable_BUILDING_FLAXFARM = processMod("25402f80-c479-4c9b-a1c0-2bc7eedf17a1", "BUILDING_FLAXFARM", "KINGDOM", 10, nil)
local unlockable_BUILDING_LIVESTOCKFARM_CATTLE = processMod("f6361b64-05d3-4ab5-a2db-b3b60dc4d307", "BUILDING_LIVESTOCKFARM_CATTLE", "KINGDOM", 10, nil)
local unlockable_BUILDING_LIVESTOCKFARM_SHEEP = processMod("f6361b64-05d3-4ab5-a2db-b3b60dc4d307", "BUILDING_LIVESTOCKFARM_SHEEP", "KINGDOM", 10, nil)
local unlockable_BUILDING_LIVESTOCKFARM_PIG = processMod("f6361b64-05d3-4ab5-a2db-b3b60dc4d307", "BUILDING_LIVESTOCKFARM_PIG", "KINGDOM", 10, nil)
local unlockable_BUILDING_LIVESTOCKFARM_GOAT = processMod("f6361b64-05d3-4ab5-a2db-b3b60dc4d307", "BUILDING_LIVESTOCKFARM_GOAT", "KINGDOM", 10, nil)
local unlockable_BUILDING_LIVESTOCKFARM_BUTCHER = processMod("f6361b64-05d3-4ab5-a2db-b3b60dc4d307", "BUILDING_LIVESTOCKFARM_BUTCHER", "KINGDOM", 10, nil)
local unlockable_BUILDING_LIVESTOCKFARM_CHANDLER = processMod("f6361b64-05d3-4ab5-a2db-b3b60dc4d307", "BUILDING_LIVESTOCKFARM_CHANDLER", "KINGDOM", 10, nil)
local unlockable_BUILDING_LIVESTOCKFARM_CREAMERY = processMod("f6361b64-05d3-4ab5-a2db-b3b60dc4d307", "BUILDING_LIVESTOCKFARM_CREAMERY", "KINGDOM", 10, nil)
local unlockable_BUILDING_BASIC_POTTER = processMod("d757c3ab-0148-4290-aa51-5559329f5640", "BUILDING_BASIC_POTTER", "KINGDOM", 10, nil)
local unlockable_JOINERWORKSHOP = processMod("4a8d3ff2-60af-4c75-8950-33e990975862", "JOINERWORKSHOP", "KINGDOM", 15, nil)
local unlockable_BUILDING_ESSENTIALS = processMod("60041e79-3595-49fc-8ce3-0a3c6d805be2", "BUILDING_ESSENTIALS", "KINGDOM", 15, nil)
local unlockable_BUILDING_FRONTIER = processMod("7c53a142-5dc3-4947-aa65-37d591ca927c", "BUILDING_FRONTIER", "KINGDOM", 10, nil)

local unlockable_BUILDING_FRONTIER_CHURCH = processMod("7c53a142-5dc3-4947-aa65-37d591ca927c", "BUILDING_FRONTIER_CHURCH", "CLERGY", 5, nil)
local unlockable_BUILDING_ORTHODOX_CHURCH = processMod("571a74ea-33d3-4340-8e0f-e7dba64d430a", "BUILDING_ORTHODOX_CHURCH", "CLERGY", 20, nil)
local unlockable_BUILDING_PAGAN = processMod("f5d1b97c-2530-4b7a-ae3e-5c904dc95471", "BUILDING_PAGAN", "CLERGY", 20, nil)
local unlockable_FANTASY_DECORATIONS = processMod("cfaa7652-e8e6-47d5-94d0-a75d49483913", "FANTASY_DECORATIONS", "CLERGY", 5, nil)
local unlockable_MEDIEVAL_FAIRE = processMod("919a50b9-938b-4572-bba7-91013b94f215", "MEDIEVAL_FAIRE", "CLERGY", 5, nil)

local unlockable_NATURE_DECORATIONS = processMod("6057d8ae-b38b-4746-bf3b-56bab3a11ec6", "NATURE_SET", "CLERGY", 5, nil)
local unlockable_MEDIEVAL_STONE_WALLS = processMod("cdb8ee0d-a218-40b9-b2c9-c596c663f7d0", "MEDIEVAL_WALLS", "KINGDOM", 10, nil)
local unlockable_STONE_GATE_SET = processMod("ad4b77eb-f903-4ade-89df-043293e696ec", "STONE_GATE_V7_MONUMENT", "KINGDOM", 20, nil)
local unlockable_WINDOWS_DECORATIONS = processMod("5d101a02-896b-4493-8fb9-29e6c9bf0684", "CUSTOM_DECORATION_V2_MONUMENT", "CLERGY", 5, nil)
local unlockable_VANIOVILLE = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_RESIDENTIAL_AREA", "LABOUR", 20, nil)
local unlockable_FISHING_SHACKS = processMod("a673e06c-5bfd-4325-bd33-398fbd9e5531", "JK_FISHING_SHACKS", "LABOUR", 10, nil)

-- Lock vanioville buildings that shouldn't be present in the first place
local unlockable_JK_HOUSE_F = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_F", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_E = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_E", "LABOUR", 20, nil)
local unlockable_JK_FOUNTAIN = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_FOUNTAIN", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_G = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_G", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_B = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_B", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_I = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_I", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_C = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_C", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_K = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_K", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_A = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_A", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_D = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_D", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_H = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_H", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_J = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_J", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_L = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_L", "LABOUR", 20, nil)
local unlockable_JK_BACKYARD_DECORATIONS = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_BACKYARD_DECORATIONS", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_R = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_R", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_T = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_T", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_S = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_S", "LABOUR", 20, nil)
local unlockable_JK_HOUSE_Q = processMod("7786b0a3-cb8f-4c78-9ba6-ca3745b7c677", "JK_HOUSE_Q", "LABOUR", 20, nil)



-- Mod quest conditions -----------------------------------------------------------------------------------
local function processModEvent(modGUID, idEvent, nameBuilding)

    if foundation.isModLoaded(modGUID) then

        mod:overrideAsset({
            Id = idEvent,
            ConditionList = {
                {
                    DataType = "GAME_CONDITION_BUILDING_AVAILABLE",
                    AssetBuilding = nameBuilding,
                },
            },
        })

    end

end

processModEvent("c8b63172-5b6d-45eb-9fab-a40c8ecd9947", "EVENT_POULTRY_START", "BUILDING_POULTRY")
processModEvent("c8b63172-5b6d-45eb-9fab-a40c8ecd9947", "EVENT_VEGETABLE_START", "BUILDING_VEGETABLEFARM")
processModEvent("9fc78b27-77d7-4f5f-96b2-464e458e3e06", "EVENT_TRADINGPOST_START", "BUILDING_TRADINGPOST")
-- livestock has a tutorial but it could be triggered by many different buildings, so leaving it out



-- Lay out Estate progression -----------------------------------------------------------------------------
-----------------------------------------------------------------------------------------------------------

-- LABOUR --------------------------------------------------------------------------
local estateLabourList1 = {
    DataType = "ESTATE_PROGRESS_TIER",
    SplendorRequired = 0,
    VillagerStatusRequired = {
        Status = "NEWCOMER",
        Quantity = 10,
    },
    UpgradeList = {
        "UNLOCKABLE_IAE_BUILDING_BUILDER_WORKSHOP",
        -- "UNLOCKABLE_IAE_BUILDING_GRANARY",
        -- "UNLOCKABLE_IAE_BUILDING_WAREHOUSE",
        "UNLOCKABLE_LABOUR_WAREHOUSE",
        unlockable_BUILDING_STORAGE,
        -- "UNLOCKABLE_IAE_MONUMENT_MARKET",
        "UNLOCKABLE_IAE_BUILDING_FISHING_HUT",
        unlockable_FISHING_SHACKS,
        unlockable_BUILDING_POULTRY,
        unlockable_BUILDING_VEGETABLEFARM,
        unlockable_BUILDING_TREEFOLK,
    },
}

local estateLabourList2 = {
    DataType = "ESTATE_PROGRESS_TIER",
    SplendorRequired = 0,
    VillagerStatusRequired = {
        Status = "SERF",
        Quantity = 20,
    },
    UpgradeList = {
        "UNLOCKABLE_IAE_BUILDING_WHEAT_FARM",
        "UNLOCKABLE_IAE_BUILDING_WINDMILL",
        "UNLOCKABLE_IAE_BUILDING_BAKERY",
        unlockable_FISHPOND,
        unlockable_BUILDING_ORCHARD,
        unlockable_BUILDING_CIDERPRESS,
        "UNLOCKABLE_LABOUR_BUILDER_WORKSHOP_SCULPTURE_WORKSHOP",
        "UNLOCKABLE_CLERGY_BUILDER_WORKSHOP_STAINED_GLASS_WORKSHOP",
        unlockable_VANIOVILLE,
        unlockable_BUILDING_TRADINGPOST,
    },
}

local estateLabourList3 = {
    DataType = "ESTATE_PROGRESS_TIER",
    SplendorRequired = 0,
    VillagerStatusRequired = {
        Status = "COMMONER",
        Quantity = 1,
    },
    UpgradeList = {
        unlockable_BUILDING_ENTERTAINMENT,
        "UNLOCKABLE_IAE_BUILDING_HOP_FARM",
        "UNLOCKABLE_IAE_BUILDING_BREWERY",
        "UNLOCKABLE_IAE_MONUMENT_TAVERN",
        "UNLOCKABLE_LABOUR_TAVERN_STONE_SET",
        unlockable_BUILDING_HARBORTRADE,
    },
}

mod:overrideAsset({
    Id = "LABOUR", -- ESTATE
    EstateProgressList = {
        estateLabourList1,
        estateLabourList2,
        estateLabourList3,
    },
})



-- KINGDOM ------------------------------------------------------------------------------------
local estateKingdomList1 = {
    DataType = "ESTATE_PROGRESS_TIER",
    SplendorRequired = 0,
    VillagerStatusRequired = {
        Status = "NEWCOMER",
        Quantity = 10,
    },
    UpgradeList = {
        "UNLOCKABLE_IAE_BUILDING_COAL_HUT",
        "UNLOCKABLE_IAE_BUILDING_STONEMASON_HUT",
        unlockable_BUILDING_ESSENTIALS,
    },
}

local switchSheep = nil
if not unlockable_BUILDING_LIVESTOCKFARM_SHEEP then
    switchSheep = "UNLOCKABLE_IAE_BUILDING_SHEEP_FARM"
end

local switchCows = nil
if not unlockable_BUILDING_LIVESTOCKFARM_CATTLE then
    switchCows = "UNLOCKABLE_IAE_BUILDING_DAIRY_FARM"
end

local estateKingdomList2 = {
    DataType = "ESTATE_PROGRESS_TIER",
    SplendorRequired = 0,
    VillagerStatusRequired = {
        Status = "SERF",
        Quantity = 20,
    },
    UpgradeList = {
        unlockable_BUILDING_BASIC_POTTER,
        -- "UNLOCKABLE_IAE_BUILDING_SHEEP_FARM",
        switchSheep,
        "UNLOCKABLE_IAE_BUILDING_WEAVER_HUT",
        "UNLOCKABLE_IAE_BUILDING_TAILOR_WORKSHOP",
        -- "UNLOCKABLE_IAE_BUILDING_DAIRY_FARM",
        switchCows,
        "UNLOCKABLE_IAE_BUILDING_CHEESE_MAKER",
        unlockable_BUILDING_FLAXFARM,
        unlockable_BUILDING_LIVESTOCKFARM_CATTLE,
        unlockable_BUILDING_LIVESTOCKFARM_SHEEP,
        unlockable_BUILDING_LIVESTOCKFARM_GOAT,
        unlockable_BUILDING_LIVESTOCKFARM_PIG,
        unlockable_BUILDING_LIVESTOCKFARM_BUTCHER,
        unlockable_BUILDING_LIVESTOCKFARM_CREAMERY,
        unlockable_BUILDING_LIVESTOCKFARM_CHANDLER,
        unlockable_STONE_GATE_SET,
        unlockable_MEDIEVAL_STONE_WALLS,
        unlockable_BUILDING_FRONTIER,
    },
}

local estateKingdomList3 = {
    DataType = "ESTATE_PROGRESS_TIER",
    SplendorRequired = 0,
    VillagerStatusRequired = {
        Status = "COMMONER",
        Quantity = 1,
    },
    UpgradeList = {
        unlockable_JOINERWORKSHOP,
        "UNLOCKABLE_LABOUR_LORD_MANOR_STONE_SET",
        "UNLOCKABLE_IAE_MONUMENT_WOODEN_KEEP",
        "UNLOCKABLE_KINGDOM_WOODEN_KEEP_DECORATIVE",
        "UNLOCKABLE_IAE_BUILDING_GLASS_SMELTER",
        "UNLOCKABLE_IAE_BUILDING_JEWELER_WORKSHOP",
        "UNLOCKABLE_IAE_BUILDING_COOPERAGE",
        "UNLOCKABLE_IAE_BUILDING_BLACKSMITH",
        "UNLOCKABLE_IAE_BUILDING_WEAPONSMITH",
    },
}

mod:overrideAsset({
    Id = "KINGDOM", -- ESTATE
    EstateProgressList = {
        estateKingdomList1,
        estateKingdomList2,
        estateKingdomList3,
    },
})



-- CLERGY --------------------------------------------------------------------------------------------------------
local estateClergyList1 = {
    DataType = "ESTATE_PROGRESS_TIER",
    SplendorRequired = 0,
    VillagerStatusRequired = {
        Status = "NEWCOMER",
        Quantity = 10,
    },
    UpgradeList = {
        unlockable_BUILDING_FRONTIER_CHURCH,
        "UNLOCKABLE_IAE_MONUMENT_RUSTIC_CHURCH",
        "UNLOCKABLE_IAE_MONUMENT_LEGACY_RUSTIC_CHURCH",
        "UNLOCKABLE_IAE_MONUMENT_ROMAN_CHURCH",
        unlockable_FANTASY_DECORATIONS,
        unlockable_MEDIEVAL_FAIRE,
        "UNLOCKABLE_CLERGY_SMALL_STONE_WALL",
        "UNLOCKABLE_KINGDOM_LARGE_STONE_WALL",
        "UNLOCKABLE_KINGDOM_WOODEN_WALL",
        "UNLOCKABLE_LABOUR_HEDGE",
        "UNLOCKABLE_LABOUR_TAVERN_WALL",
        unlockable_NATURE_DECORATIONS,
    },
}

local estateClergyList2 = {
    DataType = "ESTATE_PROGRESS_TIER",
    SplendorRequired = 0,
    VillagerStatusRequired = {
        Status = "SERF",
        Quantity = 20,
    },
    UpgradeList = {
        "UNLOCKABLE_CLERGY_RUSTIC_CHURCH_ADDITIONAL_PARTS",
        "UNLOCKABLE_IAE_MONUMENT_CHURCH",
        unlockable_BUILDING_ORTHODOX_CHURCH,
        unlockable_BUILDING_PAGAN,
        "UNLOCKABLE_IAE_MONUMENT_STONE_BRIDGE",
    },
}

local estateClergyList3 = {
    DataType = "ESTATE_PROGRESS_TIER",
    SplendorRequired = 0,
    VillagerStatusRequired = {
        Status = "COMMONER",
        Quantity = 1,
    },
    UpgradeList = {
        "UNLOCKABLE_IAE_MONUMENT_MONASTERY",
        "UNLOCKABLE_CLERGY_MONASTERY_HERB_GARDEN",
        "UNLOCKABLE_CLERGY_MONASTERY_APIARY",
        "UNLOCKABLE_CLERGY_MONASTERY_WINE_PRODUCTION",
        unlockable_WINDOWS_DECORATIONS,
    },
}

mod:overrideAsset({
    Id = "CLERGY", -- ESTATE
    EstateProgressList = {
        estateClergyList1,
        estateClergyList2,
        estateClergyList3,
    },
})
